@@ -11,8 +11,8 @@ use CLDR::Number::Constant qw( $N $M $P $C );
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION      = '0.12';
-our $CLDR_VERSION = '27.0.1';
+our $VERSION      = '0.13';
+our $CLDR_VERSION = '28';
 
 our $DATA = {
     root => {
@@ -89,8 +89,7 @@ our $DATA = {
             decimal => ',',
             group => '.',
             minus => "\N{LEFT-TO-RIGHT MARK}-",
-            nan => 'NaN',
-            percent => '%',
+            nan => 'ليس رقمًا',
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
@@ -103,8 +102,7 @@ our $DATA = {
             decimal => '.',
             group => ',',
             minus => "\N{LEFT-TO-RIGHT MARK}-",
-            nan => 'NaN',
-            percent => '%',
+            nan => 'ليس رقمًا',
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
@@ -117,8 +115,7 @@ our $DATA = {
             decimal => ',',
             group => '.',
             minus => "\N{LEFT-TO-RIGHT MARK}-",
-            nan => 'NaN',
-            percent => '%',
+            nan => 'ليس رقمًا',
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
@@ -131,8 +128,7 @@ our $DATA = {
             decimal => ',',
             group => '.',
             minus => "\N{LEFT-TO-RIGHT MARK}-",
-            nan => 'NaN',
-            percent => '%',
+            nan => 'ليس رقمًا',
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
@@ -145,8 +141,7 @@ our $DATA = {
             decimal => ',',
             group => '.',
             minus => "\N{LEFT-TO-RIGHT MARK}-",
-            nan => 'NaN',
-            percent => '%',
+            nan => 'ليس رقمًا',
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
@@ -176,6 +171,7 @@ our $DATA = {
         symbol => {
             decimal => ',',
             group => '.',
+            nan => 'ND',
         },
     },
     az => {
@@ -205,7 +201,9 @@ our $DATA = {
     },
     be => {
         pattern => {
-            currency => '¤#,##0.00',
+            at_least => '{0}+',
+            currency => '#,##0.00 ¤',
+            percent => '#,##0 %',
         },
         symbol => {
             decimal => ',',
@@ -299,6 +297,15 @@ our $DATA = {
             group => '.',
         },
     },
+    ce => {
+        pattern => {
+            currency => '#,##0.00 ¤',
+            percent => '#,##0 %',
+        },
+        symbol => {
+            nan => 'Терхьаш дац',
+        },
+    },
     cgg => {
         pattern => {
             currency => '¤#,##0.00',
@@ -309,6 +316,19 @@ our $DATA = {
             currency => '¤#,##0.00',
         },
     },
+    ckb => {
+        symbol => {
+            decimal => '٫',
+            group => '٬',
+            minus => "\N{RIGHT-TO-LEFT MARK}-",
+            percent => '٪',
+            permil => '؉',
+            plus => "\N{RIGHT-TO-LEFT MARK}+",
+        },
+        system => {
+            default => 'arab',
+        },
+    },
     cs => {
         pattern => {
             at_least => '{0}+',
@@ -324,7 +344,6 @@ our $DATA = {
         pattern => {
             at_least => '{0}+',
             currency => '¤#,##0.00',
-            range => '{0}-{1}',
         },
     },
     da => {
@@ -359,10 +378,14 @@ our $DATA = {
         pattern => {
             currency => '¤ #,##0.00',
         },
+        symbol => {
+            group => ' ',
+        },
     },
     'de-CH' => {
         pattern => {
             currency => '¤ #,##0.00;¤-#,##0.00',
+            percent => '#,##0%',
         },
         symbol => {
             decimal => '.',
@@ -372,6 +395,7 @@ our $DATA = {
     'de-LI' => {
         pattern => {
             currency => '¤ #,##0.00',
+            percent => '#,##0%',
         },
         symbol => {
             decimal => '.',
@@ -468,6 +492,12 @@ our $DATA = {
             group => '.',
         },
     },
+    'en-AT' => {
+        pattern => {
+            currency => '¤ #,##0.00',
+            percent => '#,##0 %',
+        },
+    },
     'en-BE' => {
         pattern => {
             currency => '#,##0.00 ¤',
@@ -477,6 +507,29 @@ our $DATA = {
             group => '.',
         },
     },
+    'en-CH' => {
+        pattern => {
+            currency => '¤ #,##0.00;¤-#,##0.00',
+        },
+    },
+    'en-DE' => {
+        pattern => {
+            percent => '#,##0 %',
+        },
+    },
+    'en-DK' => {
+        pattern => {
+            percent => '#,##0 %',
+        },
+    },
+    'en-FI' => {
+        pattern => {
+            percent => '#,##0 %',
+        },
+        symbol => {
+            group => ' ',
+        },
+    },
     'en-IN' => {
         pattern => {
             currency => '¤ #,##,##0.00',
@@ -484,6 +537,19 @@ our $DATA = {
             percent => '#,##,##0%',
         },
     },
+    'en-NL' => {
+        pattern => {
+            currency => '¤ #,##0.00;¤ -#,##0.00',
+        },
+    },
+    'en-SE' => {
+        pattern => {
+            percent => '#,##0 %',
+        },
+        symbol => {
+            group => ' ',
+        },
+    },
     'en-US-u-va-posix' => {
         pattern => {
             currency => '¤ #0.00',
@@ -529,6 +595,9 @@ our $DATA = {
         },
     },
     'es-AR' => {
+        pattern => {
+            currency => '¤ #,##0.00',
+        },
         symbol => {
             decimal => ',',
             group => '.',
@@ -550,6 +619,11 @@ our $DATA = {
         },
     },
     'es-CO' => {
+        pattern => {
+            currency => '¤ #,##0.00',
+            percent => '#,##0%',
+            range => 'de {0} a {1}',
+        },
         symbol => {
             decimal => ',',
             group => '.',
@@ -558,7 +632,12 @@ our $DATA = {
     'es-CR' => {
         symbol => {
             decimal => ',',
-            group => '.',
+            group => ' ',
+        },
+    },
+    'es-DO' => {
+        pattern => {
+            percent => '#,##0%',
         },
     },
     'es-EC' => {
@@ -575,6 +654,11 @@ our $DATA = {
             currency => '¤#,##0.00',
         },
     },
+    'es-GT' => {
+        pattern => {
+            range => '{0} al {1}',
+        },
+    },
     'es-MX' => {
         pattern => {
             percent => '#,##0%',
@@ -615,6 +699,7 @@ our $DATA = {
         symbol => {
             decimal => ',',
             group => ' ',
+            minus => '−',
         },
     },
     eu => {
@@ -688,14 +773,14 @@ our $DATA = {
     },
     fo => {
         pattern => {
-            currency => '¤#,##0.00;¤-#,##0.00',
+            at_least => '{0} ella meira',
+            currency => '#,##0.00 ¤',
             percent => '#,##0 %',
         },
         symbol => {
             decimal => ',',
             group => '.',
             minus => '−',
-            nan => '¤¤¤',
         },
     },
     fr => {
@@ -717,6 +802,7 @@ our $DATA = {
     'fr-CH' => {
         pattern => {
             currency => '¤ #,##0.00;¤-#,##0.00',
+            percent => '#,##0%',
         },
         symbol => {
             decimal => '.',
@@ -727,6 +813,11 @@ our $DATA = {
             group => '.',
         },
     },
+    'fr-MA' => {
+        symbol => {
+            group => '.',
+        },
+    },
     fur => {
         symbol => {
             decimal => ',',
@@ -851,9 +942,7 @@ our $DATA = {
     hy => {
         pattern => {
             at_least => '{0}+',
-            currency => '#0.00 ¤',
             decimal => '#0.###',
-            percent => '#0%',
             range => '{0}-{1}',
         },
         symbol => {
@@ -1028,7 +1117,7 @@ our $DATA = {
         pattern => {
             at_least => '{0}+',
             currency => '¤#,##0.00',
-            range => '{0}-{1}',
+            range => '{0}~{1}',
         },
     },
     kok => {
@@ -1134,6 +1223,19 @@ our $DATA = {
             nan => "ບໍ່\N{ZERO WIDTH SPACE}ແມ່ນ\N{ZERO WIDTH SPACE}ໂຕ\N{ZERO WIDTH SPACE}ເລກ",
         },
     },
+    lrc => {
+        symbol => {
+            decimal => '٫',
+            group => '٬',
+            minus => "\N{LEFT-TO-RIGHT MARK}-\N{LEFT-TO-RIGHT MARK}",
+            percent => '٪',
+            permil => '؉',
+            plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
+        },
+        system => {
+            default => 'arabext',
+        },
+    },
     lt => {
         pattern => {
             currency => '#,##0.00 ¤',
@@ -1167,7 +1269,7 @@ our $DATA = {
     lv => {
         pattern => {
             at_least => 'vismaz {0}',
-            currency => '¤#0.00',
+            currency => '#0.00 ¤',
         },
         symbol => {
             decimal => ',',
@@ -1239,7 +1341,7 @@ our $DATA = {
             currency => '¤#,##0.00',
         },
     },
-    'ms-Latn-BN' => {
+    'ms-BN' => {
         pattern => {
             currency => '¤ #,##0.00',
         },
@@ -1270,6 +1372,19 @@ our $DATA = {
             default => 'mymr',
         },
     },
+    mzn => {
+        symbol => {
+            decimal => '٫',
+            group => '٬',
+            minus => "\N{LEFT-TO-RIGHT MARK}-\N{LEFT-TO-RIGHT MARK}",
+            percent => '٪',
+            permil => '؉',
+            plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
+        },
+        system => {
+            default => 'arabext',
+        },
+    },
     naq => {
         pattern => {
             currency => '¤#,##0.00',
@@ -1278,7 +1393,6 @@ our $DATA = {
     nb => {
         pattern => {
             percent => '#,##0 %',
-            range => '{0}‒{1}',
         },
         symbol => {
             decimal => ',',
@@ -1585,6 +1699,7 @@ our $DATA = {
             at_least => '{0}+',
             currency => '#,##0.00 ¤',
             percent => '#,##0 %',
+            range => '{0} – {1}',
         },
         symbol => {
             decimal => ',',
@@ -1719,6 +1834,18 @@ our $DATA = {
             currency => '¤#,##0.00',
         },
     },
+    tk => {
+        pattern => {
+            at_least => '≥{0}',
+            currency => '#,##0.00 ¤',
+            percent => '#,##0 %',
+        },
+        symbol => {
+            decimal => ',',
+            group => ' ',
+            nan => 'san däl',
+        },
+    },
     to => {
         pattern => {
             at_least => '{0}+',
@@ -1770,7 +1897,6 @@ our $DATA = {
         symbol => {
             decimal => ',',
             group => ' ',
-            nan => 'Не число',
         },
     },
     ur => {
@@ -1793,9 +1919,14 @@ our $DATA = {
         },
     },
     uz => {
+        pattern => {
+            at_least => '{0}+',
+            currency => '#,##0.00 ¤',
+        },
         symbol => {
             decimal => ',',
             group => ' ',
+            nan => 'haqiqiy son emas',
         },
     },
     'uz-Arab' => {
@@ -1830,7 +1961,6 @@ our $DATA = {
     vi => {
         pattern => {
             at_least => '{0}+',
-            currency => '#,##0.00 ¤',
             range => '{0}-{1}',
         },
         symbol => {
@@ -1881,24 +2011,10 @@ our $DATA = {
     zh => {
         pattern => {
             at_least => '{0}+',
+            currency => '¤#,##0.00',
             range => '{0}-{1}',
         },
     },
-    'zh-Hans-HK' => {
-        pattern => {
-            currency => '¤#,##0.00',
-        },
-    },
-    'zh-Hans-MO' => {
-        pattern => {
-            currency => '¤#,##0.00',
-        },
-    },
-    'zh-Hans-SG' => {
-        pattern => {
-            currency => '¤#,##0.00',
-        },
-    },
     'zh-Hant' => {
         pattern => {
             at_least => '{0}+',
@@ -1914,39 +2030,37 @@ our $DATA = {
             at_least => '{0}+',
             currency => '¤#,##0.00',
         },
-        symbol => {
-            nan => 'I-NaN',
-        },
     },
     map { $_ => undef } qw(
         af-NA ar-AE ar-BH ar-DJ ar-EG ar-ER ar-IL ar-IQ ar-JO ar-KM ar-KW ar-LB
         ar-MR ar-OM ar-PS ar-QA ar-SA ar-SD ar-SO ar-SS ar-SY ar-TD ar-YE
-        az-Latn bm-Latn bn-IN bo bo-IN bs-Latn ca-AD ca-ES-u-va-valencia ca-FR
-        ca-IT da-GL de-BE de-LU ee-TG el-CY en-001 en-AG en-AI en-AS en-AU en-BB
-        en-BM en-BS en-BW en-BZ en-CA en-CC en-CK en-CM en-CX en-DG en-DM en-ER
-        en-FJ en-FK en-FM en-GB en-GD en-GG en-GH en-GI en-GM en-GU en-GY en-HK
-        en-IE en-IM en-IO en-JE en-JM en-KE en-KI en-KN en-KY en-LC en-LR en-LS
-        en-MG en-MH en-MO en-MP en-MS en-MT en-MU en-MW en-MY en-NA en-NF en-NG
-        en-NR en-NU en-NZ en-PG en-PH en-PK en-PN en-PR en-PW en-RW en-SB en-SC
-        en-SD en-SG en-SH en-SL en-SS en-SX en-SZ en-TC en-TK en-TO en-TT en-TV
-        en-TZ en-UG en-UM en-VC en-VG en-VI en-VU en-WS en-ZM en-ZW es-CU es-DO
-        es-EA es-GT es-HN es-IC es-NI es-PA es-PE es-PH es-PR es-SV es-US fa-AF
-        ff-CM ff-GN ff-MR fr-BF fr-BI fr-BJ fr-BL fr-CA fr-CD fr-CF fr-CG fr-CI
-        fr-CM fr-DJ fr-DZ fr-GA fr-GF fr-GN fr-GP fr-GQ fr-HT fr-KM fr-MA fr-MC
-        fr-MF fr-MG fr-ML fr-MQ fr-MR fr-MU fr-NC fr-NE fr-PF fr-PM fr-RE fr-RW
-        fr-SC fr-SN fr-SY fr-TD fr-TG fr-TN fr-VU fr-WF fr-YT gsw-FR gsw-LI ha
-        ha-Latn ha-Latn-GH ha-Latn-NE hr-BA ii it-SM kk-Cyrl ko-KP ks-Arab
-        ky-Cyrl lag lkt ln-AO ln-CF ln-CG mas-TZ mgo mn-Cyrl ms-Latn ms-Latn-SG
-        nb-SJ ne-IN nl-AW nl-BQ nl-CW nl-SR nl-SX om-KE os-RU pa-Guru pt-AO
-        pt-CV pt-GW pt-MO pt-MZ pt-ST pt-TL qu-EC ro-MD ru-BY ru-KG ru-KZ ru-MD
-        ru-UA sah se-FI se-SE shi-Tfng so-DJ so-ET so-KE sq-MK sq-XK sr-Cyrl
-        sr-Cyrl-BA sr-Cyrl-ME sr-Cyrl-XK sr-Latn-BA sr-Latn-ME sr-Latn-XK sv-AX
-        sv-FI sw-KE sw-UG ta-LK teo-KE ti-ER tr-CY tzm-Latn ug-Arab uz-Latn
-        vai-Vaii yi yo-BJ zh-Hans zh-Hant-HK zh-Hant-MO
+        az-Latn bn-IN bo bo-IN bs-Latn ca-AD ca-ES-u-va-valencia ca-FR ca-IT
+        ckb-IR cu da-GL de-BE de-LU ee-TG el-CY en-001 en-AG en-AI en-AS en-AU
+        en-BB en-BI en-BM en-BS en-BW en-BZ en-CA en-CC en-CK en-CM en-CX en-CY
+        en-DG en-DM en-ER en-FJ en-FK en-FM en-GB en-GD en-GG en-GH en-GI en-GM
+        en-GU en-GY en-HK en-IE en-IL en-IM en-IO en-JE en-JM en-KE en-KI en-KN
+        en-KY en-LC en-LR en-LS en-MG en-MH en-MO en-MP en-MS en-MT en-MU en-MW
+        en-MY en-NA en-NF en-NG en-NR en-NU en-NZ en-PG en-PH en-PK en-PN en-PR
+        en-PW en-RW en-SB en-SC en-SD en-SG en-SH en-SI en-SL en-SS en-SX en-SZ
+        en-TC en-TK en-TO en-TT en-TV en-TZ en-UG en-UM en-VC en-VG en-VI en-VU
+        en-WS en-ZM en-ZW es-CU es-EA es-HN es-IC es-NI es-PA es-PE es-PH es-PR
+        es-SV es-US fa-AF ff-CM ff-GN ff-MR fo-DK fr-BF fr-BI fr-BJ fr-BL fr-CA
+        fr-CD fr-CF fr-CG fr-CI fr-CM fr-DJ fr-DZ fr-GA fr-GF fr-GN fr-GP fr-GQ
+        fr-HT fr-KM fr-MC fr-MF fr-MG fr-ML fr-MQ fr-MR fr-MU fr-NC fr-NE fr-PF
+        fr-PM fr-RE fr-RW fr-SC fr-SN fr-SY fr-TD fr-TG fr-TN fr-VU fr-WF fr-YT
+        gsw-FR gsw-LI ha ha-GH ha-NE hr-BA ii it-SM ko-KP lag lkt ln-AO ln-CF
+        ln-CG lrc-IQ mas-TZ mgo ms-SG nb-SJ ne-IN nl-AW nl-BQ nl-CW nl-SR nl-SX
+        om-KE os-RU pa-Guru prg pt-AO pt-CV pt-GW pt-MO pt-MZ pt-ST pt-TL qu-EC
+        ro-MD ru-BY ru-KG ru-KZ ru-MD ru-UA sah se-FI se-SE shi-Tfng so-DJ so-ET
+        so-KE sq-MK sq-XK sr-Cyrl sr-Cyrl-BA sr-Cyrl-ME sr-Cyrl-XK sr-Latn-BA
+        sr-Latn-ME sr-Latn-XK sv-AX sv-FI sw-KE sw-UG ta-LK teo-KE ti-ER tr-CY
+        uz-Latn vai-Vaii vo yi yo-BJ zh-Hans zh-Hans-HK zh-Hans-MO zh-Hans-SG
+        zh-Hant-HK zh-Hant-MO
     )
 };
 
 our $PARENT = {
+    'az-Arab' => 'root',
     'az-Cyrl' => 'root',
     'bm-Nkoo' => 'root',
     'bs-Cyrl' => 'root',
@@ -1978,6 +2092,7 @@ our $PARENT = {
     'en-CK' => 'en-001',
     'en-CM' => 'en-001',
     'en-CX' => 'en-001',
+    'en-CY' => 'en-001',
     'en-DG' => 'en-001',
     'en-DM' => 'en-001',
     'en-ER' => 'en-001',
@@ -1993,6 +2108,7 @@ our $PARENT = {
     'en-GY' => 'en-001',
     'en-HK' => 'en-001',
     'en-IE' => 'en-001',
+    'en-IL' => 'en-001',
     'en-IM' => 'en-001',
     'en-IN' => 'en-001',
     'en-IO' => 'en-001',
@@ -2047,6 +2163,14 @@ our $PARENT = {
     'en-ZA' => 'en-001',
     'en-ZM' => 'en-001',
     'en-ZW' => 'en-001',
+    'en-AT' => 'en-150',
+    'en-CH' => 'en-150',
+    'en-DE' => 'en-150',
+    'en-DK' => 'en-150',
+    'en-FI' => 'en-150',
+    'en-NL' => 'en-150',
+    'en-SE' => 'en-150',
+    'en-SI' => 'en-150',
     'es-AR' => 'es-419',
     'es-BO' => 'es-419',
     'es-CL' => 'es-419',
